@@ -59,6 +59,8 @@ class KuCoin(Feed):
         lookup = {'1m': '1min', '3m': '3min', '15m': '15min', '30m': '30min', '1h': '1hour', '2h': '2hour', '4h': '4hour', '6h': '6hour', '8h': '8hour', '12h': '12hour', '1d': '1day', '1w': '1week'}
         self.candle_interval = lookup[self.candle_interval]
         self.normalize_interval = {value: key for key, value in lookup.items()}
+        if any([len(self.subscription[chan]) > 300 for chan in self.subscription]):
+            raise ValueError("Kucoin has a limit of 300 symbols per connection")
         self.__reset()
 
     def __reset(self):
@@ -237,8 +239,16 @@ class KuCoin(Feed):
 
     async def message_handler(self, msg: str, conn, timestamp: float):
         msg = json.loads(msg, parse_float=Decimal)
-        if msg['type'] in {'welcome', 'ack'}:
-            return
+
+        if 'topic' not in msg:
+            if msg['type'] == 'error':
+                LOG.warning("%s: error from exchange %s", self.id, msg)
+                return
+            elif msg['type'] in {'welcome', 'ack'}:
+                return
+            else:
+                LOG.warning("%s: Unhandled message type %s", self.id, msg)
+                return
 
         topic, symbol = msg['topic'].split(":", 1)
         topic = self.exchange_channel_to_std(topic)
@@ -257,7 +267,7 @@ class KuCoin(Feed):
     async def subscribe(self, conn: AsyncConnection):
         self.__reset()
         for chan in self.subscription:
-            symbols = self.subscription[chan]
+            symbols = list(self.subscription[chan])
             nchan = self.exchange_channel_to_std(chan)
             if nchan == CANDLES:
                 for symbol in symbols:
@@ -269,10 +279,11 @@ class KuCoin(Feed):
                         'response': True
                     }))
             else:
-                await conn.write(json.dumps({
-                    'id': 1,
-                    'type': 'subscribe',
-                    'topic': f"{chan}:{','.join(symbols)}",
-                    'privateChannel': False,
-                    'response': True
-                }))
+                for slice_index in range(0, len(symbols), 100):
+                    await conn.write(json.dumps({
+                        'id': 1,
+                        'type': 'subscribe',
+                        'topic': f"{chan}:{','.join(symbols[slice_index: slice_index+100])}",
+                        'privateChannel': False,
+                        'response': True
+                    }))
